<h3 align="center"><img src="IMG_0760.png" alt="logo" height="250px"></h3>

<p align="center">
    <b>Bucket WSGI</b><br>
    <br>
    The Bucket WSGI is a compex program that lets the user create outstanding.
    <br>Web applications with such simplicity.
    <br>
    <br>
    <b>Installation</b><br>
    <br>
    <code>pip3 install jump-wsgi</code>
</p>

